import smbus
import time

bus = smbus.SMBus(1)

AXP209_CHIP_VERSION = 0x3
AXP209_DCDC2_VOLTAGE = 0x23
AXP209_DCDC3_VOLTAGE = 0x27
AXP209_LDO24_VOLTAGE = 0x28
AXP209_LDO3_VOLTAGE = 0x29
AXP209_SHUTDOWN = 0x32

def reg_read(addr):
	global bus
	return bus.read_byte_data(0x34, addr)

def reg_write(addr, val):
	global bus
	bus.write_byte_data(0x34, addr, val)


def set_ldo2(mvolt):

	cfg = (mvolt - 1800) / 100

	if (cfg < 0):
		cfg = 0
	if (cfg > 15):
		cfg = 15

	reg = reg_read(AXP209_LDO24_VOLTAGE)
	reg = (reg & 0x0f) | (cfg << 4)
	reg_write(AXP209_LDO24_VOLTAGE, reg)

def set_ldo3(mvolt):

	cfg = (mvolt - 700) / 25

	if (cfg < 0):
		cfg = 0
	if (cfg > 127):
		cfg = 127
	if (mvolt == -1):
		cfg = 0x80	# detemined by LDO3IN pin

	reg_write(AXP209_LDO3_VOLTAGE, cfg)



def set_ldo4(mvolt):

	vindex = [
		1250, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000, 2500,
		2700, 2800, 3000, 3100, 3200, 3300
	]

	# Translate mvolt to register cfg value, requested <= selected
	cfg = 0
	for v in vindex:
		if mvolt <= v:
			break
		cfg += 1

	reg = reg_read(AXP209_LDO24_VOLTAGE)
	print mvolt, cfg, hex(reg)

	# LDO4 configuration is in lower 4 bits
	reg = (reg & 0xf0) | cfg 
	print mvolt, cfg, hex(reg)
	reg_write(AXP209_LDO24_VOLTAGE, reg)

